@@ -12,11 +12,15 @@ class S3Bucket(Resource):
         "BucketEncryption": PropertyType(False, any_type()),
         "BucketName": PropertyType(False, is_str()),
         "CorsConfiguration": PropertyType(False, any_type()),
+        "IntelligentTieringConfigurations": PropertyType(False, any_type()),
         "InventoryConfigurations": PropertyType(False, any_type()),
         "LifecycleConfiguration": PropertyType(False, any_type()),
         "LoggingConfiguration": PropertyType(False, any_type()),
         "MetricsConfigurations": PropertyType(False, any_type()),
         "NotificationConfiguration": PropertyType(False, is_type(dict)),
+        "ObjectLockConfiguration": PropertyType(False, any_type()),
+        "ObjectLockEnabled": PropertyType(False, any_type()),
+        "OwnershipControls": PropertyType(False, any_type()),
         "PublicAccessBlockConfiguration": PropertyType(False, is_type(dict)),
         "ReplicationConfiguration": PropertyType(False, any_type()),
         "Tags": PropertyType(False, is_type(list)),
