@@ -1,7 +1,13 @@
 import boto3
 
 
+class NoRegionFound(Exception):
+    pass
+
+
 class ArnGenerator(object):
+    class_boto_session = None
+
     @classmethod
     def generate_arn(cls, partition, service, resource, include_account_id=True):
         if not service or not resource:
@@ -43,7 +49,17 @@ class ArnGenerator(object):
         if region is None:
             # Use Boto3 to get the region where code is running. This uses Boto's regular region resolution
             # mechanism, starting from AWS_DEFAULT_REGION environment variable.
-            region = boto3.session.Session().region_name
+
+            if ArnGenerator.class_boto_session is None:
+                region = boto3.session.Session().region_name
+            else:
+                region = ArnGenerator.class_boto_session.region_name
+
+        # If region is still None, then we could not find the region. This will only happen
+        # in the local context. When this is deployed, we will be able to find the region like
+        # we did before.
+        if region is None:
+            raise NoRegionFound("AWS Region cannot be found")
 
         # setting default partition to aws, this will be overwritten by checking the region below
         partition = "aws"
