@@ -1,3 +1,8 @@
+import logging
+
+LOG = logging.getLogger(__name__)
+
+
 class ManagedPolicyLoader(object):
     def __init__(self, iam_client):
         self._iam_client = iam_client
@@ -5,6 +10,7 @@ class ManagedPolicyLoader(object):
 
     def load(self):
         if self._policy_map is None:
+            LOG.info("Loading policies from IAM...")
             paginator = self._iam_client.get_paginator("list_policies")
             # Setting the scope to AWS limits the returned values to only AWS Managed Policies and will
             # not returned policies owned by any specific account.
@@ -15,5 +21,6 @@ class ManagedPolicyLoader(object):
             for page in page_iterator:
                 name_to_arn_map.update(map(lambda x: (x["PolicyName"], x["Arn"]), page["Policies"]))
 
+            LOG.info("Finished loading policies from IAM.")
             self._policy_map = name_to_arn_map
         return self._policy_map
